@@ -59,13 +59,14 @@ class Errorable:
 class Repeated(Errorable):
     """Class to make a "repeated" protobuf attribute pythonic."""
 
-    def __init__(self, name, pb_field, cleaner=None):
+    def __init__(self, name, pb_field, cleaner=None, nodups=False):
         """Initialize a repeated field named pf_field in the protobuf, with an optional
            cleaner function that checks/cleans the data and returns a clean copy."""
         super().__init__()
         self.name = name
         self.pb_field = pb_field
         self.cleaner = cleaner
+        self.nodups = nodups
 
     def _clean(self, value):
         if self.cleaner:
@@ -99,16 +100,22 @@ class Repeated(Errorable):
     def append(self, value):
         value = self._clean(value)
         if value is not None:
+            if self.nodups and value in self.pb_field:
+                return
             self.pb_field.append(value)
 
     def insert(self, i, value):
         value = self._clean(value)
         if value is not None:
+            if self.nodups and value in self.pb_field:
+                return
             self.pb_field.insert(i, value)
 
     def extend(self, values):
         if self.cleaner:
             values = [self._clean(value) for value in values]
+        if self.nodups:
+            values = [x for x in set(values) if x not in self.pb_field]
         self.pb_field.extend([x for x in values if x is not None])
 
     def __repr__(self):
@@ -122,11 +129,15 @@ class Attachment(Errorable):
     def __init__(self, pb=None, **kwargs):
         super().__init__()
         self.pb = pb if pb else service_pb2.Attachment()
-        self._mac_addresses = Repeated('mac_addresses', self.pb.mac_addresses,
-                                       _validate_mac)
+        self._mac_addresses = Repeated('mac_addresses',
+                                       self.pb.mac_addresses,
+                                       _validate_mac,
+                                       nodups=True)
         self._mac_addresses.error_parent = self
-        self._network_prefixes = Repeated('network_prefixes', self.pb.network_prefixes,
-                                          _validate_ip)
+        self._network_prefixes = Repeated('network_prefixes',
+                                          self.pb.network_prefixes,
+                                          _validate_ip,
+                                          nodups=True)
         self._network_prefixes.error_parent = self
         for key, value in kwargs.items():
             setattr(self, key, value)
