@@ -479,3 +479,42 @@ class TestSourceModel(unittest.TestCase):
         del attachment2.network_prefixes[0]
         attachment1.network_prefixes[0] = '2001:db8:1234::/48'
         self.assertEqual(attachment1, attachment2)
+
+    def test_attachment_network_prefixes_no_dups(self):
+        attachment1 = Attachment()
+        attachment1.network_prefixes.append('192.0.2.1')
+        self.assertEqual(len(attachment1.network_prefixes), 1)
+        self.assertEqual(attachment1.network_prefixes[0], '192.0.2.1')
+
+        attachment1.network_prefixes.append('192.0.2.1')
+        self.assertEqual(len(attachment1.network_prefixes), 1)
+        self.assertEqual(attachment1.network_prefixes[0], '192.0.2.1')
+
+        attachment1 = Attachment()
+        attachment1.network_prefixes.extend(['192.0.2.1/32', '192.0.2.1'])
+        self.assertEqual(len(attachment1.network_prefixes), 1)
+        self.assertEqual(attachment1.network_prefixes[0], '192.0.2.1')
+
+        attachment1.network_prefixes.extend(['192.0.2.1/32', '192.0.2.1'])
+        self.assertEqual(len(attachment1.network_prefixes), 1)
+        self.assertEqual(attachment1.network_prefixes[0], '192.0.2.1')
+
+    def test_attachment_mac_addresses_no_dups(self):
+        mac = '00:11:22:33:44:55'
+        attachment1 = Attachment()
+        attachment1.mac_addresses.append(mac)
+        self.assertEqual(len(attachment1.mac_addresses), 1)
+        self.assertEqual(attachment1.mac_addresses[0], mac)
+
+        attachment1.mac_addresses.append(mac)
+        self.assertEqual(len(attachment1.mac_addresses), 1)
+        self.assertEqual(attachment1.mac_addresses[0], mac)
+
+        attachment1 = Attachment()
+        attachment1.mac_addresses.extend([mac, '0:11:22:33:44:55'])
+        self.assertEqual(len(attachment1.mac_addresses), 1)
+        self.assertEqual(attachment1.mac_addresses[0], mac)
+
+        attachment1.mac_addresses.extend([mac, '0:11:22:33:44:55'])
+        self.assertEqual(len(attachment1.mac_addresses), 1)
+        self.assertEqual(attachment1.mac_addresses[0], mac)
